<span class="radioset">
	<input type="radio" name="cdr|download" id="cdr|download_yes" value="yes" <?php echo ($download) ? 'checked' : ''?>>
	<label for="cdr|download_yes">Yes</label>
	<input type="radio" name="cdr|download" id="cdr|download_no" value="no" <?php echo !($download) ? 'checked' : ''?>>
	<label for="cdr|download_no">No</label>
</span>
<br/>
