<span class="radioset">
	<input type="radio" name="cdr|playback" id="cdr|playback_yes" value="yes" <?php echo ($playback) ? 'checked' : ''?>>
	<label for="cdr|playback_yes">Yes</label>
	<input type="radio" name="cdr|playback" id="cdr|playback_no" value="no" <?php echo !($playback) ? 'checked' : ''?>>
	<label for="cdr|playback_no">No</label>
</span>
<br/>
